[**高級選項**](./introduction.md) > **語言代碼** _(current)_

---

#### Google

來源 <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>，由 GPT-4o 整理。

| 中文標籤 | 標籤 | `語言代碼` |
| --- | --- | --- |
| 阿姆哈拉語 | Amharic | `am` |
| 阿拉伯语 | Arabic | `ar` |
| 巴斯克語 | Basque | `eu` |
| 孟加拉语 | Bengali | `bn` |
| 英語（英國） | English (UK) | `en-GB` |
| 葡萄牙語（巴西） | Portuguese (Brazil) | `pt-BR` |
| 保加利亞語 | Bulgarian | `bg` |
| 加泰羅尼亞語 | Catalan | `ca` |
| 切羅基語 | Cherokee | `chr` |
| 克羅埃西亞語 | Croatian | `hr` |
| 捷克语 | Czech | `cs` |
| 丹麥語 | Danish | `da` |
| 荷蘭語 | Dutch | `nl` |
| 英語（美國） | English (US) | `en` |
| 愛沙尼亞語 | Estonian | `et` |
| 菲律賓語 | Filipino | `fil` |
| 芬蘭語 | Finnish | `fi` |
| 法語 | French | `fr` |
| 德語 | German | `de` |
| 希臘語 | Greek | `el` |
| 古吉拉特语 | Gujarati | `gu` |
| 希伯來語 | Hebrew | `iw` |
| 印地语 | Hindi | `hi` |
| 匈牙利語 | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
| 印度尼西亚语 | Indonesian | `id` |
| 意大利語 | Italian | `it` |
| 日語 | Japanese | `ja` |
| 卡纳达语 | Kannada | `kn` |
| 韓語 | Korean | `ko` |
| 拉脫維亞語 | Latvian | `lv` |
| 立陶宛语 | Lithuanian | `lt` |
| 馬來語 | Malay | `ms` |
| 馬拉雅拉姆語 | Malayalam | `ml` |
| 馬拉地語 | Marathi | `mr` |
| 挪威语 | Norwegian | `no` |
| 波蘭語 | Polish | `pl` |
| 葡萄牙語（葡萄牙） | Portuguese (Portugal) | `pt-PT` |
| 羅馬尼亞語 | Romanian | `ro` |
| 俄語 | Russian | `ru` |
| 塞爾維亞語 | Serbian | `sr` |
| 中文（台灣） | Chinese (Taiwan) | `zh-TW` |
| 斯洛伐克语 | Slovak | `sk` |
| 斯洛文尼亚语 | Slovenian | `sl` |
| 西班牙语 | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| 瑞典语 | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 泰语 | Thai | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| 土耳其語 | Turkish | `tr` |
| 烏爾都語 | Urdu | `ur` |
| 烏克蘭語 | Ukrainian | `uk` |
| 越南语 | Vietnamese | `vi` |
| 威爾斯語 | Welsh | `cy` |


#### DeepL
來源 <https://developers.deepl.com/docs/resources/supported-languages>，由 GPT-4o 整理。

| 中文標籤 | 標籤 | `語言代碼` | 支援類型 |
| --- | --- | --- | --- |
| 阿拉伯語 | Arabic | `AR` | `source`, `target` |
| 保加利亞語 | Bulgarian | `BG` | `source`, `target` |
| 捷克语 | Czech | `CS` | `source`, `target` |
| 丹麥語 | Danish | `DA` | `source`, `target` |
| 德語 | German | `DE` | `source`, `target` |
| 希腊语 | Greek | `EL` | `source`, `target` |
| 英語 | English | `EN` | `source`, `target` |
| 英語（英國） | English (British) | `EN-GB` | `target` |
| 英語（美國） | English (American) | `EN-US` | `target` |
| 西班牙语 | Spanish | `ES` | `source`, `target` |
| 愛沙尼亞語 | Estonian | `ET` | `source`, `target` |
| 芬蘭語 | Finnish | `FI` | `source`, `target` |
| 法语 | French | `FR` | `source`, `target` |
| 匈牙利語 | Hungarian | `HU` | `source`, `target` |
| 印尼語 | Indonesian | `ID` | `source`, `target` |
| 意大利语 | Italian | `IT` | `source`, `target` |
| 日語 | Japanese | `JA` | `source`, `target` |
| 韓語 | Korean | `KO` | `source`, `target` |
| 立陶宛语 | Lithuanian | `LT` | `source`, `target` |
| 拉脫維亞語 | Latvian | `LV` | `source`, `target` |
| 挪威博克马尔语 | Norwegian Bokmål | `NB` | `source`, `target` |
| 荷蘭語 | Dutch | `NL` | `source`, `target` |
| 波蘭語 | Polish | `PL` | `source`, `target` |
| 葡萄牙語 | Portuguese | `PT` | `source`, `target` |
| 葡萄牙語（巴西） | Portuguese (Brazilian) | `PT-BR` | `target` |
| 葡萄牙語（歐洲） | Portuguese (European) | `PT-PT` | `target` |
| 羅馬尼亞語 | Romanian | `RO` | `source`, `target` |
| 俄语 | Russian | `RU` | `source`, `target` |
| 斯洛伐克语 | Slovak | `SK` | `source`, `target` |
| 斯洛文尼亞語 | Slovenian | `SL` | `source`, `target` |
| 瑞典语 | Swedish | `SV` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| 烏克蘭語 | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chinese | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁體） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Some content on this page has been translated by GPT and may contain errors.</small></h6>